@@ -39,10 +39,10 @@ except:
 
 
 CATEGORY_TO_PACKAGE = {
-    "VIDEO": "xorg",
     "SOUND": "alsa-base"}
 
 CATEGORY_TO_SYMPTOM = {
+    "VIDEO": "display",
     "DISK":  "storage"}
 
 
