@@ -18,15 +18,15 @@
 #
 from gettext import gettext as _
 
-from checkbox.lib.iterator import PREV
-
 from checkbox.plugin import Plugin
+from checkbox.user_interface import PREV
 
 
 class ReportPrompt(Plugin):
 
     def register(self, manager):
         super(ReportPrompt, self).register(manager)
+
         self._manager.reactor.call_on("prompt-report", self.prompt_report)
 
     def prompt_report(self, interface):
